Django-view-sets
================

Installation
------------
Install using pip:

.. code-block:: sh

    $ pip install django-view-sets

Add to installed apps:

.. code-block:: python

    INSTALLED_APPS = (
        ...
        'viewsets',
        ...
    )
